@@ -41,7 +41,7 @@ my $COMPRESS_FILE_EXTENSIONS_OR_ALL = sub { qr/(:?$_[0])/ }
         map {$COMPRESS_FILE_EXTENSIONS->value($_) }
           $COMPRESS_FILE_EXTENSIONS->all));
 
-sub files {
+sub visit_installed_files {
     my ($self, $file) = @_;
 
     if (   $file->is_regular_file
@@ -52,7 +52,7 @@ sub files {
         # see #785662
         if (index($file->name,'oui') > -1 || index($file->name,'iab') > -1) {
 
-            $self->tag('package-installs-ieee-data', $file->name)
+            $self->hint('package-installs-ieee-data', $file->name)
               unless $self->processable->source eq 'ieee-data';
         }
     }
