@@ -1,9 +1,9 @@
 # -*- perl -*-
 # Lintian::Spelling -- Lintian spelling checks shared between multiple scripts
 
-# Copyright (C) 2009 Russ Allbery
-# Copyright (C) 2004 Marc Brockschmidt
-# Copyright (C) 1998 Richard Braakman
+# Copyright © 2009 Russ Allbery
+# Copyright © 2004 Marc Brockschmidt
+# Copyright © 1998 Richard Braakman
 #
 # This program is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by the Free
@@ -20,13 +20,13 @@
 
 package Lintian::Spelling;
 
-use strict;
+use v5.20;
 use warnings;
+use utf8;
 
 use Exporter qw(import);
 
 use Lintian::Data;
-use Lintian::Util qw(strip);
 
 use constant DOUBLE_QUOTE => q{"};
 
@@ -120,7 +120,9 @@ sub check_spelling {
     $text =~ s/(\w-)\s*\n\s*/$1/;
     $text =~ tr/\r\n \t/ /s;
     $text =~ s/\s++/ /g;
-    strip($text);
+
+    # trim both ends
+    $text =~ s/^\s+|\s+$//g;
 
     for my $word (split(' ', $text)) {
         my $ends_with_punct = 0;
@@ -227,7 +229,10 @@ sub check_spelling_picky {
     $text =~ s/\[.+?\]//sg;
     $text =~ tr/\r\n \t/ /s;
     $text =~ s/\s++/ /g;
-    strip($text);
+
+    # trim both ends
+    $text =~ s/^\s+|\s+$//g;
+
     for my $word (split(/\s+/, $text)) {
         $word =~ s/^\(|[).,?!:;]+$//g;
         if ($corrections_case->known($word)) {
